==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/VirtualGatewayAccessLog.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class VirtualGatewayAccessLog(
    file: Option[zio.aws.appmesh.model.VirtualGatewayFileAccessLog] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog = {
    import VirtualGatewayAccessLog.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
      .builder()
      .optionallyWith(file.map(value => value.buildAwsValue()))(_.file)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.VirtualGatewayAccessLog.ReadOnly =
    zio.aws.appmesh.model.VirtualGatewayAccessLog.wrap(buildAwsValue())
}
object VirtualGatewayAccessLog {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.VirtualGatewayAccessLog =
      zio.aws.appmesh.model
        .VirtualGatewayAccessLog(file.map(value => value.asEditable))
    def file: Option[zio.aws.appmesh.model.VirtualGatewayFileAccessLog.ReadOnly]
    def getFile: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualGatewayFileAccessLog.ReadOnly
    ] = AwsError.unwrapOptionField("file", file)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
  ) extends zio.aws.appmesh.model.VirtualGatewayAccessLog.ReadOnly {
    override val file
        : Option[zio.aws.appmesh.model.VirtualGatewayFileAccessLog.ReadOnly] =
      scala
        .Option(impl.file())
        .map(value =>
          zio.aws.appmesh.model.VirtualGatewayFileAccessLog.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
  ): zio.aws.appmesh.model.VirtualGatewayAccessLog.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_3-5.17.206.1-sources.jar: zio/aws/appmesh/model/VirtualGatewayAccessLog.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class VirtualGatewayAccessLog(
    file: Optional[zio.aws.appmesh.model.VirtualGatewayFileAccessLog] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog = {
    import VirtualGatewayAccessLog.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
      .builder()
      .optionallyWith(file.map(value => value.buildAwsValue()))(_.file)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.VirtualGatewayAccessLog.ReadOnly =
    zio.aws.appmesh.model.VirtualGatewayAccessLog.wrap(buildAwsValue())
}
object VirtualGatewayAccessLog {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.VirtualGatewayAccessLog =
      zio.aws.appmesh.model
        .VirtualGatewayAccessLog(file.map(value => value.asEditable))
    def file
        : Optional[zio.aws.appmesh.model.VirtualGatewayFileAccessLog.ReadOnly]
    def getFile: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualGatewayFileAccessLog.ReadOnly
    ] = AwsError.unwrapOptionField("file", file)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
  ) extends zio.aws.appmesh.model.VirtualGatewayAccessLog.ReadOnly {
    override val file
        : Optional[zio.aws.appmesh.model.VirtualGatewayFileAccessLog.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.file())
        .map(value =>
          zio.aws.appmesh.model.VirtualGatewayFileAccessLog.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.VirtualGatewayAccessLog
  ): zio.aws.appmesh.model.VirtualGatewayAccessLog.ReadOnly = new Wrapper(impl)
}
